### ----------------------------------------
### Tick-pathogen model Rstanarm
### NPS tick drag data 2014-2022
### Code created by A. Martin
### Email: alynn.martin89@gmail.com
### ----------------------------------------
### MODEL04 Pathogen and deer management


### L O A D   P A C K A G E S

library(rstanarm)
library(rstan)
library(bayesrules)
library(tidyverse)
library(bayesplot)
library(tidybayes)



### L O A D  D A T A

data04 <- read.table(file="XXX.txt")  ## load tabular data using download name



### M O D E L  04

stan_mod04 <- stan_glm(
  
  cbind(Number_Bbss, Bbss_uninfected) ~ palmerz_may + relative_humidity_april + relative_humidity_may + lagged_binned_deer_management * park_id,

  data=data04, 
  
  family=binomial(link = "logit"), 
  
  prior_intercept = normal(0,2.0),
  
  prior = normal(0,2.0), 
  
  importance_resampling=TRUE, keep_every=10,
  
  chains = 3, iter = 30000*2, seed = 1000

  )



###  M O D E L   O U T P U T

## summary

summary(stan_mod04)

coef(stan_mod04)

stan_mod04$coefficients

tidy(stan_mod04, effects = "fixed", conf.int = TRUE, conf.level = 0.95)

tidy(stan_mod04, effects = "ran_vals", conf.int = TRUE, conf.level = 0.95)


## trace plots

trace <- plot(stan_mod04, "trace", pars=(c("(Intercept)", "palmerz_may", "relative_humidity_april", "relative_humidity_may")))


## plotting fixed variable effect

plot(stan_mod04, pars =c("(Intercept)", "palmerz_may", "relative_humidity_april", "relative_humidity_may"), prob=0.5, prob_outer=0.95)



### P O S T - H O C   A N A L Y S I S 

library(emmeans)

emmeans(stan_mod04, pairwise ~ lagged_binned_deer_management | park_id) 

